@@ -77,7 +77,8 @@ namespace Banshee
             new Translator("\u00D8ivind Hoel", "Norwegian Bokm\u00E5l"),
             new Translator("Marco Carvalho", "Brazilian Portuguese"),
 			new Translator("Christian Rose", "Swedish"),
-			new Translator("Lasse Bang Mikkelsen", "Danish")
+			new Translator("Lasse Bang Mikkelsen", "Danish"),
+			new Translator("Stephane Raimbault", "French")
         };
     
         private class Translator : IComparable
@@ -142,7 +143,7 @@ namespace Banshee
             about_dialog.Authors = Authors;
             about_dialog.TranslatorCredits = Translator.ToString(Translators);
             about_dialog.Artists = Artists;
-            about_dialog.Icon = ThemeIcons.WindowManager;
+            IconThemeUtils.SetWindowIcon(about_dialog);
             about_dialog.Logo = Gdk.Pixbuf.LoadFromResource("banshee-logo.png");
             about_dialog.License = Resource.GetFileContents("COPYING");
             about_dialog.WrapLicense = true;
@@ -162,6 +163,7 @@ namespace Banshee
                 null,
                 Translator.ToString(Translators),
                 Gdk.Pixbuf.LoadFromResource("banshee-logo.png"));
+            IconThemeUtils.SetWindowIcon(about_dialog);
             about_dialog.Run();
             about_dialog.Destroy();
         }
