@@ -169,11 +169,13 @@ namespace Banshee
             
             Core.Log.Updated += OnLogCoreUpdated;
             
+            ImportManager.Instance.ImportRequested += OnImportManagerImportRequested;
+            
             //InitialLoadTimeout();
             GLib.Timeout.Add(500, InitialLoadTimeout);
             WindowPlayer.Show();
             
-            try {
+            /*try {
                 if((bool)Globals.Configuration.Get(GConfKeys.EnableSpecialKeys)) {
                     special_keys = new SpecialKeys();
                     special_keys.Delay = new TimeSpan(350 * TimeSpan.TicksPerMillisecond);
@@ -187,7 +189,7 @@ namespace Banshee
             } catch(Exception e) {
                 special_keys = null;
                 Core.Log.PushWarning(Catalog.GetString("Could not setup special keys"), e.Message, false);
-            }   
+            }*/
         }
    
         private bool InitialLoadTimeout()
@@ -198,6 +200,8 @@ namespace Banshee
             
             foreach(DapDevice device in DapCore.Devices) {
                  device.PropertiesChanged += OnDapPropertiesChanged;
+                 device.SaveStarted += OnDapSaveStarted;
+                 device.SaveFinished += OnDapSaveFinished;
             }
             
             if(Core.ArgumentQueue.Contains("audio-cd")) {
@@ -256,11 +260,11 @@ namespace Banshee
         private void BuildWindow()
         {
             // Icons and Pixbufs
-            WindowPlayer.Icon = ThemeIcons.WindowManager;
+            IconThemeUtils.SetWindowIcon(WindowPlayer);
             
-            ImagePrevious.SetFromStock("media-prev", IconSize.LargeToolbar);
-            ImageNext.SetFromStock("media-next", IconSize.LargeToolbar);
-            ImagePlayPause.SetFromStock("media-play", IconSize.LargeToolbar);
+            ImagePrevious.Pixbuf = IconThemeUtils.LoadIcon("media-skip-backward", 22);
+            ImageNext.Pixbuf = IconThemeUtils.LoadIcon("media-skip-forward", 22);
+            ImagePlayPause.Pixbuf = IconThemeUtils.LoadIcon("media-playback-start", 22);
             
             ImageBurn.SetFromStock("media-burn", IconSize.LargeToolbar);
             ImageRip.SetFromStock("media-rip", IconSize.LargeToolbar);
@@ -366,14 +370,12 @@ namespace Banshee
             box.PackStart(dapSyncButton, false, false, 0);
             dapSyncButton.ShowAll();
             
-            dapPropertiesButton = new Button(
-                new Gtk.Image("gtk-properties", IconSize.Menu));
+            dapPropertiesButton = new Button(new Gtk.Image(IconThemeUtils.LoadIcon("document-properties", 22)));
             dapPropertiesButton.Clicked += OnDapPropertiesClicked;
             box.PackStart(dapPropertiesButton, false, false, 0);
             dapPropertiesButton.ShowAll();
             
-            dapEjectButton = new Button(new Gtk.Image("media-eject",
-                IconSize.Menu));
+            dapEjectButton = new Button(new Gtk.Image(IconThemeUtils.LoadIcon("media-eject", 22)));
             dapEjectButton.Clicked += OnDapEjectClicked;
             box.PackStart(dapEjectButton, false, false, 0);
             dapEjectButton.ShowAll();
@@ -402,8 +404,10 @@ namespace Banshee
             searchEntry.EnterPress += OnSimpleSearch;
             searchEntry.Changed += OnSimpleSearch;
             searchEntry.Show();
-            ((HBox)gxml["PlaylistHeaderBox"]).PackStart(searchEntry, 
-                false, false, 0);
+            ((HBox)gxml["PlaylistHeaderBox"]).PackStart(searchEntry, false, false, 0);
+                
+            gxml["SearchLabel"].Sensitive = false;
+            searchEntry.Sensitive = false;
                 
             // Repeat/Shuffle buttons
             
@@ -586,6 +590,9 @@ namespace Banshee
             ((Gtk.ScrolledWindow)gxml["SourceContainer"]).Remove(sourceViewLoadingVP);
             ((Gtk.ScrolledWindow)gxml["SourceContainer"]).Add(sourceView);
             sourceView.Show();
+            
+            gxml["SearchLabel"].Sensitive = true;
+            searchEntry.Sensitive = true;
         }
         
         private void OnLibraryTransactionStatusStopped(object o, EventArgs args)
@@ -656,17 +663,17 @@ namespace Banshee
         public void TogglePlaying()
         {
             if(Core.Instance.Player.Playing) {
-                ImagePlayPause.SetFromStock("media-play", IconSize.LargeToolbar);
+                ImagePlayPause.Pixbuf = IconThemeUtils.LoadIcon("media-playback-start", 22);
                 Core.Instance.Player.Pause();
                 
                 if(trayIcon != null) {
-                    ((Gtk.Image)trayIcon.PlayItem.Image).SetFromStock("media-play", IconSize.Menu);
+                    ((Gtk.Image)trayIcon.PlayItem.Image).Pixbuf = IconThemeUtils.LoadIcon("media-playback-start", 16);
                 }
             } else {
-                ImagePlayPause.SetFromStock("media-pause", IconSize.LargeToolbar);
+                ImagePlayPause.Pixbuf = IconThemeUtils.LoadIcon("media-playback-pause", 22);
                 Core.Instance.Player.Play();
                 if(trayIcon != null) {
-                    ((Gtk.Image)trayIcon.PlayItem.Image).SetFromStock("media-pause", IconSize.Menu);
+                    ((Gtk.Image)trayIcon.PlayItem.Image).Pixbuf = IconThemeUtils.LoadIcon("media-playback-pause", 16);
                 }
             }
         }
@@ -1083,38 +1090,24 @@ namespace Banshee
             );
             
             try {
-                 chooser.SetCurrentFolderUri(Core.GconfClient.Get(
-                     GConfKeys.LastFileSelectorUri) as string);
+                 chooser.SetCurrentFolderUri(Core.GconfClient.Get(GConfKeys.LastFileSelectorUri) as string);
             } catch(Exception) {
-                 chooser.SetCurrentFolder(Environment.GetFolderPath(
-                    Environment.SpecialFolder.Personal));
+                 chooser.SetCurrentFolder(Environment.GetFolderPath(Environment.SpecialFolder.Personal));
             }
             
             chooser.AddButton(Stock.Cancel, ResponseType.Cancel);
             chooser.AddButton(Stock.Open, ResponseType.Ok);
             chooser.DefaultResponse = ResponseType.Ok;
             
-            if(chooser.Run() == (int)ResponseType.Ok) 
-                ImportMusic(chooser.Uri);
-                
-            Core.GconfClient.Set(GConfKeys.LastFileSelectorUri,
-                 chooser.CurrentFolderUri);
+            if(chooser.Run() == (int)ResponseType.Ok) { 
+                ImportManager.Instance.QueueSource(chooser.Uri);
+            }
+            
+            Core.GconfClient.Set(GConfKeys.LastFileSelectorUri, chooser.CurrentFolderUri);
             
             chooser.Destroy();
         }
-        
-        private void ImportMusic(string path)
-        {
-            if(sourceView.SelectedSource.Type == SourceType.Library &&
-                searchEntry.Query == String.Empty) {
-                playlistModel.AddFile(path);
-            } else {
-                FileLoadTransaction loader = new FileLoadTransaction(path);
-                loader.HaveTrackInfo += OnLoaderHaveTrackInfo;
-                loader.Register();
-            }
-        }
-        
+
         private void OnLoaderHaveTrackInfo(object o, HaveTrackInfoArgs args)
         {
             sourceView.QueueDraw();
@@ -1123,7 +1116,7 @@ namespace Banshee
         
         private void ImportHomeDirectory()
         {
-            ImportMusic(Environment.GetFolderPath(Environment.SpecialFolder.Personal));
+            ImportManager.Instance.QueueSource(Environment.GetFolderPath(Environment.SpecialFolder.Personal));
         }
 
         private void OnMenuImportFolderActivate(object o, EventArgs args)
@@ -1140,11 +1133,9 @@ namespace Banshee
             );
             
             try {
-                 chooser.SetCurrentFolderUri(Core.GconfClient.Get(
-                     GConfKeys.LastFileSelectorUri) as string);
+                 chooser.SetCurrentFolderUri(Core.GconfClient.Get(GConfKeys.LastFileSelectorUri) as string);
             } catch(Exception) {
-                 chooser.SetCurrentFolder(Environment.GetFolderPath(
-                    Environment.SpecialFolder.Personal));
+                 chooser.SetCurrentFolder(Environment.GetFolderPath(Environment.SpecialFolder.Personal));
             }
             
             chooser.AddButton(Stock.Cancel, ResponseType.Cancel);
@@ -1154,13 +1145,10 @@ namespace Banshee
             chooser.DefaultResponse = ResponseType.Ok;
             
             if(chooser.Run() == (int)ResponseType.Ok) {
-                foreach(string path in chooser.Uris) {
-                    ImportMusic(path);
-                }
+                ImportManager.Instance.QueueSource(chooser.Uris);
             }
             
-            Core.GconfClient.Set(GConfKeys.LastFileSelectorUri,
-                 chooser.CurrentFolderUri);
+            Core.GconfClient.Set(GConfKeys.LastFileSelectorUri, chooser.CurrentFolderUri);
             
             chooser.Destroy();
         }
@@ -1276,14 +1264,11 @@ namespace Banshee
                 gxml["DapContainer"].Visible = false;
             }     
                  
-            gxml["SearchLabel"].Sensitive = source.Type == SourceType.Dap 
+            gxml["SearchLabel"].Sensitive = (source.Type == SourceType.Dap && !((source as DapSource).IsSyncing)) 
                  || source.Type == SourceType.Library;
             searchEntry.Sensitive = gxml["SearchLabel"].Sensitive;
             playlistView.SyncColumn.Visible = source.Type == SourceType.Dap;
             playlistView.RipColumn.Visible = source.Type == SourceType.AudioCd;
-            
-            playlistModel.ImportCanUpdate = source.Type == SourceType.Library
-                && searchEntry.Query == String.Empty;
                 
             if(source.Type != SourceType.Dap)
                 ShowPlaylistView();
@@ -1308,7 +1293,7 @@ namespace Banshee
                 toolTips.SetTip(dapDiskUsageBar, tooltip, tooltip);
             });
         }
-        
+
         private void OnDapPropertiesChanged(object o, EventArgs args)
         {
             Application.Invoke(delegate {
@@ -1333,6 +1318,8 @@ namespace Banshee
         private void OnDapCoreDeviceAdded(object o, DapEventArgs args)
         {
             args.Dap.PropertiesChanged += OnDapPropertiesChanged;
+            args.Dap.SaveStarted += OnDapSaveStarted;
+            args.Dap.SaveFinished += OnDapSaveFinished;
         }
         
         private void OnAudioCdCoreDiskRemoved(object o, AudioCdCoreDiskRemovedArgs args)
@@ -1391,68 +1378,32 @@ namespace Banshee
             if(sourceView.SelectedSource.Type != SourceType.Dap)
                 return;
                 
-           LogCore.Instance.PushWarning(Catalog.GetString("iPod Syncing Disabled"), 
-                Catalog.GetString("iPod syncing has been disabled in this release because unified DAP " + 
-                "support is under development, and the iPod sync code has not yet been converted to " + 
-                "the DAP sync model. iPod syncing will be back in the next release."));
+            DapSource dapSource = sourceView.SelectedSource as DapSource;
         
-           /* IpodSource ipodSource = sourceView.SelectedSource as IpodSource;
-            IpodSync sync = null;
-            
-            if(!ipodSource.Device.CanWrite)
-                 return;
-        
-            if(ipodSource.NeedSync) {
-                HigMessageDialog md = new HigMessageDialog(WindowPlayer, 
-                    DialogFlags.DestroyWithParent, MessageType.Question,
-                    Catalog.GetString("Synchronize iPod"),
-                    Catalog.GetString("You have made changes to your iPod. Please choose " +
+            HigMessageDialog md = new HigMessageDialog(WindowPlayer, 
+                DialogFlags.DestroyWithParent, MessageType.Question,
+                Catalog.GetString("Synchronize iPod"),
+                Catalog.GetString("You have made changes to your iPod. Please choose " +
                     "a method for updating the contents of your iPod.\n\n" + 
                     "<i>Synchronize Library</i>: synchronize Banshee library to iPod\n" +
                     "<i>Save Manual Changes</i>: save only the manual changes you made\n\n" +
                     "<b>Warning:</b> Actions will alter or erase existing iPod contents and may cause incompatability with iTunes!"),
-                    Catalog.GetString("Synchronize Library"));
-                    md.AddButton(Catalog.GetString("Save Manual Changes"), 
-                        Gtk.ResponseType.Apply, true);
-                md.Image = IpodMisc.GetIcon(ipodSource.Device, 48);
-                md.Icon = md.Image;
-                switch(md.Run()) {
-                    case (int)ResponseType.Ok:
-                        sync = ipodSource.Sync(true);
-                        sync.SyncStarted += OnIpodSyncStarted;
-                        sync.SyncCompleted += OnIpodSyncCompleted;
-                        sync.StartSync();
-                        break;
-                    case (int)ResponseType.Apply:
-                        sync = ipodSource.Sync(false);
-                        sync.SyncStarted += OnIpodSyncStarted;
-                        sync.SyncCompleted += OnIpodSyncCompleted;
-                        sync.StartSync();
-                        break;
-                }
-                
-                md.Destroy();
-            } else {
-                HigMessageDialog md = new HigMessageDialog(WindowPlayer, 
-                    DialogFlags.DestroyWithParent, MessageType.Question,
-                    Catalog.GetString("Synchronize iPod"),
-                    Catalog.GetString("Are you sure you want to synchronize your iPod " +
-                    "with your Banshee library? This will <b>erase</b> the contents of " +
-                    "your iPod and then copy the contents of your Banshee library."),
-                    Catalog.GetString("Synchronize Library"));
-                md.Image = IpodMisc.GetIcon(ipodSource.Device, 48);
-                md.Icon = md.Image;
-                switch(md.Run()) {
-                    case (int)ResponseType.Ok:
-                        sync = ipodSource.Sync(true);
-                        sync.SyncStarted += OnIpodSyncStarted;
-                        sync.SyncCompleted += OnIpodSyncCompleted;
-                        sync.StartSync();
-                        break;
-                }
-                
-                md.Destroy();
-            }*/
+                Catalog.GetString("Synchronize Library"));
+            
+            md.AddButton(Catalog.GetString("Save Manual Changes"), Gtk.ResponseType.Apply, true);
+            md.Image = dapSource.Device.GetIcon(48);
+            md.Icon = md.Image;
+            
+            switch(md.Run()) {
+                case (int)ResponseType.Ok:
+                    dapSource.Device.Save(Core.Library.Tracks.Values);
+                    break;
+                case (int)ResponseType.Apply:
+                    dapSource.Device.Save();
+                    break;
+            }
+
+            md.Destroy();
         }
         
         private void OnDapEjectClicked(object o, EventArgs args)
@@ -1460,7 +1411,7 @@ namespace Banshee
             EjectSource(sourceView.SelectedSource);
         }
         
-        private void OnDapSyncStarted(object o, EventArgs args)
+        private void OnDapSaveStarted(object o, EventArgs args)
         {
             if(playlistModel.Source.Type == SourceType.Dap 
                 && (playlistModel.Source as DapSource).IsSyncing) {
@@ -1475,7 +1426,7 @@ namespace Banshee
             }
         }
         
-        private void OnDapSyncCompleted(object o, EventArgs args)
+        private void OnDapSaveFinished(object o, EventArgs args)
         {
             if(playlistModel.Source.Type == SourceType.Dap 
                 && !(playlistModel.Source as DapSource).IsSyncing) {
@@ -1924,29 +1875,62 @@ namespace Banshee
             playlistView.Selection.UnselectAll();
         }
         
+        private bool DoesTrackMatchSearch(TrackInfo ti)
+        {
+            if(!searchEntry.IsQueryAvailable) {
+                return false;
+            }
+            
+            string query = searchEntry.Query.ToLower();
+            string field = searchEntry.Field;
+            string match = null;
+            
+            if(field == Catalog.GetString("Artist Name")) {
+                match = ti.Artist;
+            } else if(field == Catalog.GetString("Song Name")) {
+                match = ti.Title;
+            } else if(field == Catalog.GetString("Album Title")) {
+                match = ti.Album;
+            } else {
+                string [] matches = {
+                    ti.Artist,
+                    ti.Album,
+                    ti.Title
+                };
+
+                foreach(string m in matches) {
+                    if(m == null || m == String.Empty) {
+                        continue;
+                    }
+
+                    string ml = m.ToLower();
+                    if(ml.IndexOf(query) >= 0 || ml.IndexOf("the " + query) >= 0) {
+                        return true;
+                    }
+                }
+                
+                return false;
+            }
+                    
+            match = match.ToLower();
+            return match.IndexOf(query) >= 0 || match.IndexOf("the " + query) >= 0;
+        }
+        
         private void OnSimpleSearch(object o, EventArgs args)
         {
             Source source = sourceView.SelectedSource;
             playlistModel.Clear();
             
-            string query = searchEntry.Query;
-            string field = searchEntry.Field;
-            
-            
-            playlistModel.ImportCanUpdate = 
-                query == null || query == String.Empty;
-            
-            if(query == null || query == String.Empty) {
-                if(source.Type == SourceType.Dap)
+            if(!searchEntry.IsQueryAvailable) {
+                if(source.Type == SourceType.Dap) {
                     playlistModel.LoadFromDapSource(source as DapSource);
-                else
+                } else {
                     playlistModel.LoadFromLibrary();
+                }
                 
                 return;
             }
             
-            query = query.ToLower();
-            
             ICollection collection = null;
             
             if(source.Type == SourceType.Dap) {
@@ -1956,41 +1940,10 @@ namespace Banshee
             }
             
             foreach(TrackInfo ti in collection) {
-                string match;
-                
                 try {
-                    if(field == Catalog.GetString("Artist Name"))
-                        match = ti.Artist;
-                    else if(field == Catalog.GetString("Song Name"))
-                        match = ti.Title;
-                    else if(field == Catalog.GetString("Album Title"))
-                        match = ti.Album;
-                    else {
-                        string [] matches = {
-                            ti.Artist,
-                            ti.Album,
-                            ti.Title
-                        };
-
-                        foreach(string m in matches) {
-                            if (m == null)
-                                continue;
-                            
-                            string ml = m.ToLower();
-                            if(ml.IndexOf(query) >= 0
-                               || ml.IndexOf("the " + query) >= 0) {
-                                playlistModel.AddTrack(ti);
-                                break;
-                            }
-                        }
-
-                        continue;
-                    }
-                    
-                    match = match.ToLower();
-                    if(match.IndexOf(query) >= 0
-                        || match.IndexOf("the " + query) >= 0)
+                    if(DoesTrackMatchSearch(ti)) {
                         playlistModel.AddTrack(ti);
+                    }
                 } catch(Exception) {
                     continue;
                 }
@@ -2227,9 +2180,9 @@ namespace Banshee
                     // If in Playlist view, we append Library *AND* PlayList
                     // If in SmartPlaylist View WE DO NOT ACCEPT DND
                 
-                    if(rawSelectionData != null 
-                        && rawSelectionData.Trim().Length > 0)
-                        ImportMusic(rawSelectionData);
+                    if(rawSelectionData != null) {
+                        ImportManager.Instance.QueueSource(args.SelectionData);
+                    }
                         
                     break;
                 case (uint)Dnd.TargetType.PlaylistRows:
@@ -2349,6 +2302,7 @@ namespace Banshee
         private void OnButtonRipClicked(object o, EventArgs args)
         {
             RipTransaction trans = new RipTransaction();
+            trans.HaveTrackInfo += OnRipTransactionTrackRipped;
 
             foreach(object [] node in playlistModel) {
                 if(node[0] is AudioCdTrackInfo && ((AudioCdTrackInfo)node[0]).CanRip) {
@@ -2369,6 +2323,19 @@ namespace Banshee
             }
         }
         
+        private void OnRipTransactionTrackRipped(object o, HaveTrackInfoArgs args)
+        {
+            if(playlistModel.Source is LibrarySource) {
+                ThreadAssist.ProxyToMain(delegate {
+                    if(searchEntry.IsQueryAvailable && !DoesTrackMatchSearch(args.TrackInfo)) {
+                        return;
+                    }
+
+                    playlistModel.AddTrack(args.TrackInfo);
+                });
+            }
+        }
+        
         private void EjectSource(Source source)
         {
             if(source.CanEject) {
@@ -2483,5 +2450,29 @@ namespace Banshee
             alignment.Add(syncing_container);
             alignment.ShowAll();
         }
+        
+        private void OnImportManagerImportRequested(object o, ImportEventArgs args)
+        {
+            try {
+                TrackInfo ti = new LibraryTrackInfo(args.FileName);
+                args.ReturnMessage = String.Format("{0} - {1}", ti.Artist, ti.Title);
+                if(playlistModel.Source is LibrarySource) {
+                    ThreadAssist.ProxyToMain(delegate {
+                        if(searchEntry.IsQueryAvailable && !DoesTrackMatchSearch(ti)) {
+                            return;
+                        }
+                        
+                        playlistModel.AddTrack(ti);
+                    });
+                }
+            } catch(Entagged.Audioformats.Exceptions.CannotReadException) {
+                Console.WriteLine(Catalog.GetString("Cannot Import") + ": {0}", args.FileName);
+                args.ReturnMessage = Catalog.GetString("Scanning") + "...";
+            } catch(Exception e) {
+                Console.WriteLine(Catalog.GetString("Cannot Import: {0} ({1}, {2})"), 
+                    args.FileName, e.GetType(), e.Message);
+                args.ReturnMessage = Catalog.GetString("Scanning") + "...";
+            }
+        }
     }
 }
