@@ -32,6 +32,8 @@ using System.Collections;
 using Mono.Unix;
 using Gtk;
 
+using Banshee.Widgets;
+
 namespace Banshee
 {
 	public class TrackInfoHeader : HBox
@@ -74,13 +76,13 @@ namespace Banshee
 			imageTitleIcon.Xalign = 0.0f;
 			imageTitleIcon.Yalign = 0.5f;
 			
-			artistLabel = new Label();
+			artistLabel = new EllipsizeLabel();
 			artistLabel.Show();
 			artistLabel.Xalign = 0.0f;
 			artistLabel.Yalign = 0.5f;
 			artistLabel.Selectable = true;
 			
-			titleLabel = new Label();
+			titleLabel = new EllipsizeLabel();
 			titleLabel.Show();			
 			titleLabel.Xalign = 0.0f;
 			titleLabel.Yalign = 0.5f;
@@ -103,12 +105,12 @@ namespace Banshee
 				(AttachOptions)0, 0, 0);
 			
 			// Album Picture
-			imageAlbum = new Image();
+			/*imageAlbum = new Image();
 			imageAlbum.Show();
 			imageAlbum.Pixbuf = 
 				Gdk.Pixbuf.LoadFromResource("album-cover-container.png");
 
-			PackStart(imageAlbum, false, false, 5);
+			PackStart(imageAlbum, false, false, 5);*/
 						
 			SetIdle();
 		}
@@ -116,8 +118,7 @@ namespace Banshee
 		public string Artist 
 		{
 			set {
-				artistLabel.Markup = "<b>" + 
-					GLib.Markup.EscapeText(StringUtil.EntityEscape(value)) + "</b>";
+				artistLabel.Markup = "<b>" + GLib.Markup.EscapeText(value) + "</b>";
 			}
 		}
 		
